//
//  ContentMainTabAlarmViewModel.swift
//  SodaLive
//
//  Created by klaus on 2/22/25.
//

import Foundation
import Combine

final class ContentMainTabAlarmViewModel: ObservableObject {
    private let repository = ContentMainTabAlarmRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var bannerList: [GetAudioContentBannerResponse] = []
    @Published var alarmThemeList: [String] = []
    @Published var newAlarmContentList: [GetAudioContentMainItem] = []
    @Published var rankAlarmContentList: [GetAudioContentRankingItem] = []
    @Published var eventBannerList: [EventItem] = []
    @Published var curationList: [GetContentCurationResponse] = []
    
    func fetchData() {
        isLoading = true
        repository.getContentMainAlarm()
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponse<GetContentMainTabAlarmResponse>.self, from: responseData)
                    
                    if let data = decoded.data, decoded.success {
                        self.bannerList = data.contentBannerList
                        self.alarmThemeList = ["전체"] + data.alarmThemeList
                        self.newAlarmContentList = data.newAlarmContentList
                        self.rankAlarmContentList = data.rankAlarmContentList
                        self.eventBannerList = data.eventBannerList.eventList
                        self.curationList = data.curationList
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
                
                self.isLoading = false
            }
            .store(in: &subscription)
    }
    
    func getContentMainAlarm(theme: String) {
        isLoading = true
        repository.getContentMainAlarmAll(theme: theme)
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponse<GetNewContentAllResponse>.self, from: responseData)
                    
                    if let data = decoded.data, decoded.success {
                        self.newAlarmContentList = data.items
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
                
                self.isLoading = false
            }
            .store(in: &subscription)
    }
}
